@@ -321,6 +321,12 @@ tar_map2_run_rep <- function(
     }
   )
   if_any(anyNA(seed), NULL, targets::tar_seed_set(seed = seed))
+  step_set(
+    step = step_tar_rep,
+    batch = batch,
+    rep = rep,
+    reps = length(seeds)
+  )
   out <- eval(command, envir = envir)
   out <- tar_append_static_values(out, values[, columns])
   out[["tar_batch"]] <- as.integer(batch)
